"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OtpController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const loopback4_authorization_1 = require("loopback4-authorization");
const core_1 = require("@sourceloop/core");
const otpCacheTtl = 900000;
let OtpController = /** @class */ (() => {
    let OtpController = class OtpController {
        constructor(otpRepository) {
            this.otpRepository = otpRepository;
        }
        async create(otp) {
            await this.otpRepository.set(otp.username, otp, { ttl: otpCacheTtl });
        }
        async findById(id) {
            return this.otpRepository.get(id);
        }
        async deleteById(id) {
            await this.otpRepository.delete(id);
        }
    };
    tslib_1.__decorate([
        loopback4_authorization_1.authorize(['*']),
        rest_1.post('/otp-caches', {
            responses: {
                [200 /* OK */]: {
                    description: 'Otp model instance',
                    content: { [core_1.CONTENT_TYPE.JSON]: { schema: rest_1.getModelSchemaRef(models_1.Otp) } },
                },
            },
        }),
        tslib_1.__param(0, rest_1.requestBody({
            content: {
                [core_1.CONTENT_TYPE.JSON]: {
                    schema: rest_1.getModelSchemaRef(models_1.Otp),
                },
            },
        })),
        tslib_1.__metadata("design:type", Function),
        tslib_1.__metadata("design:paramtypes", [models_1.Otp]),
        tslib_1.__metadata("design:returntype", Promise)
    ], OtpController.prototype, "create", null);
    tslib_1.__decorate([
        loopback4_authorization_1.authorize(['*']),
        rest_1.get('/otp-caches/{id}', {
            responses: {
                [200 /* OK */]: {
                    description: 'Otp model instance',
                    content: { [core_1.CONTENT_TYPE.JSON]: { schema: rest_1.getModelSchemaRef(models_1.Otp) } },
                },
            },
        }),
        tslib_1.__param(0, rest_1.param.path.string('id')),
        tslib_1.__metadata("design:type", Function),
        tslib_1.__metadata("design:paramtypes", [String]),
        tslib_1.__metadata("design:returntype", Promise)
    ], OtpController.prototype, "findById", null);
    tslib_1.__decorate([
        loopback4_authorization_1.authorize(['*']),
        rest_1.del('/otp-caches/{id}', {
            responses: {
                '204': {
                    description: 'Otp DELETE success',
                },
            },
        }),
        tslib_1.__param(0, rest_1.param.path.string('id')),
        tslib_1.__metadata("design:type", Function),
        tslib_1.__metadata("design:paramtypes", [String]),
        tslib_1.__metadata("design:returntype", Promise)
    ], OtpController.prototype, "deleteById", null);
    OtpController = tslib_1.__decorate([
        tslib_1.__param(0, repository_1.repository(repositories_1.OtpRepository)),
        tslib_1.__metadata("design:paramtypes", [repositories_1.OtpRepository])
    ], OtpController);
    return OtpController;
})();
exports.OtpController = OtpController;
//# sourceMappingURL=otp.controller.js.map